@@ -140,13 +140,15 @@ def iterate_meta_rfs(mirror_rp, inc_rp):
 	raw_rfs = iterate_raw_rfs(mirror_rp, inc_rp)
 	collated = rorpiter.Collate2Iters(raw_rfs, yield_metadata())
 	for raw_rf, metadata_rorp in collated:
-		if not raw_rf:
+		if raw_rf:
+			raw_rf.set_metadata_rorp(metadata_rorp)
+			yield raw_rf
+		else:
 			log.Log("Warning, metadata file has entry for %s,\n"
 					"but there are no associated files." %
 					(metadata_rorp.get_indexpath(),), 2)
-			continue
-		raw_rf.set_metadata_rorp(metadata_rorp)
-		yield raw_rf
+			yield RegressFile(mirror_rp.new_index(metadata_rorp.index),
+							  inc_rp.new_index(metadata_rorp.index), ())
 
 
 class RegressFile(restore.RestoreFile):
